---
keywords:
  - 페이먼트월
  - 일반결제
  - 정기결제
  - 결제연동
  - 채널설정방법
  - 채널추가
title: 페이먼트월 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: 페이먼트월 채널설정방법
  description: >-
    페이먼트월 결제 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 결제대행사와 연동방식별로
    설정하는 정보는 상이할 수 있습니다.
tags:
  - 페이먼트월
  - 결제
  - 채널설정방법
pgCompanies:
  - 페이먼트월
searchTags:
  - 페이먼트월
  - 페이먼트월실연동
  - 페이먼트월테스트
  - 페이먼트월채널설정
  - 페이먼트월연동
  - 페이먼트월설정
  - 해외결제
datetime: 2023-11-30T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Callout content="[연동방식]
- 결제창 : 결제대행사(PG사)의 결제창을 띄워서 그 안에서 결제수단 선택 후 결제하는 방식
- API : 직접 구현한 UI를 통해 결제 수단 정보를 입력받아 API를 통해 결제하는 방식

[모듈버전]
- V1 : 포트원 결제모듈 V1. 다양한 결제대행사와 수단을 지원
- V2 : 포트원 차세대 결제 모듈로 직관적인 인터페이스를 지원
- 신모듈 : 결제대행사의 최신 버전의 모듈
- 구모듈 : 결제대행사의 구 버전의 모듈

[결제방식]
- 일반결제 : 구매자의 결제정보를 저장하지 않는 일회성 결제 (단건결제)
- 정기결제 : 구매자의 결제정보를 저장해놓고 재결제하는 결제 (정기 / 비 정기결제)
" title="참고사항" icon="💡" />

## <Highlight text="결제창 일반결제 및 API 수기/정기결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. 페이먼트월에서 범용적인 key를 제공하지 않아 고객사별 테스트용 key 발급이 필요합니다.  key 발급을 위해 포트원 관리자콘솔 [전자결제 신청]으로 접수해주시기 바랍니다.
2. 페이먼트월 테스트모드의 경우 실제 카드로 테스트가 진행되어야 하며, **실제 결제가 발생**되므로 반드시 **취소처리까지 진행**해주셔야 합니다.
3. 국가별 결제수단의 정책에 따라 취소(환불)이 불가한 국가/결제수단이 있을 수 있습니다.
4. **페이먼트월 정책상 결제를 시도하는 국가IP에 따라 결제수단이 노출됩니다.**
**(국내에서 해외결제를 테스트 하실 경우, 해당 국가의 vpn을 이용하여 IP변경 후 시도해주시면 됩니다)**
5. 결제수단 제어는 페이먼트월 홈페이지 내에서 Project를 활성화시킨 뒤 제어하실 수 있습니다.
(별도로 제어하지 않으시면 국가IP에 맞는 결제수단이 기본으로 노출됩니다)" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 페이먼트월
  - 결제모듈 : 결제창 일반결제 및 API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID)  : 페이먼트월 가입신청 후 페이먼트월 관리자페이지에 접속하여 테스트(Sandbox) project key 를 확인할 수 있습니다. (가입신청 전 이용 불가)
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : 페이먼트월
  - 결제모듈 : 결제창 일반결제 및 API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디(Project Key) : 운영용 project key 입력 (페이먼트월 상점관리자페이지 로그인하여 key확인가능)
- Secret Key : 운영용 secret key 입력 (페이먼트월 상점관리자페이지 로그인하여 key확인가능)
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="페이먼트월 개발가이드 보러가기↗" />
